@@ -27,7 +27,6 @@
 #include "pango-utils.h"
 #include "pango-fontmap.h"
 #include "pangoatsui.h"
-#include "pangocairo-atsuifont.h"
 
 /* No extra fields needed */
 typedef PangoEngineShape      BasicEngineATSUI;
@@ -37,33 +36,6 @@ typedef PangoEngineShapeClass BasicEngineATSUIClass ;
 #define RENDER_TYPE PANGO_RENDER_TYPE_ATSUI
 
 static PangoEngineScriptInfo basic_scripts[] = {
-  { PANGO_SCRIPT_ARMENIAN, "*" },
-  { PANGO_SCRIPT_BOPOMOFO, "*" },
-  { PANGO_SCRIPT_CHEROKEE, "*" },
-  { PANGO_SCRIPT_COPTIC,   "*" },
-  { PANGO_SCRIPT_CYRILLIC, "*" },
-  { PANGO_SCRIPT_DESERET,  "*" },
-  { PANGO_SCRIPT_ETHIOPIC, "*" },
-  { PANGO_SCRIPT_GEORGIAN, "*" },
-  { PANGO_SCRIPT_GOTHIC,   "*" },
-  { PANGO_SCRIPT_GREEK,    "*" },
-  { PANGO_SCRIPT_HAN,      "*" },
-  { PANGO_SCRIPT_HIRAGANA, "*" },
-  { PANGO_SCRIPT_KATAKANA, "*" },
-  { PANGO_SCRIPT_LATIN,    "*" },
-  { PANGO_SCRIPT_OGHAM,    "*" },
-  { PANGO_SCRIPT_OLD_ITALIC, "*" },
-  { PANGO_SCRIPT_RUNIC,     "*" },
-  { PANGO_SCRIPT_CANADIAN_ABORIGINAL, "*" },
-  { PANGO_SCRIPT_YI,       "*" },
-  { PANGO_SCRIPT_BRAILLE,  "*" },
-  { PANGO_SCRIPT_CYPRIOT,  "*" },
-  { PANGO_SCRIPT_LIMBU,    "*" },
-  { PANGO_SCRIPT_OSMANYA,  "*" },
-  { PANGO_SCRIPT_SHAVIAN,  "*" },
-  { PANGO_SCRIPT_LINEAR_B, "*" },
-  { PANGO_SCRIPT_UGARITIC, "*" },
-
   { PANGO_SCRIPT_COMMON,   "" }
 };
 
@@ -112,14 +84,12 @@ basic_engine_shape (PangoEngineShape    *engine,
   ItemCount glyph_count;
   int i;
   const char *p;
-  PangoCairoATSUIFont *cafont = PANGO_CAIRO_ATSUI_FONT (font);
+  PangoATSUIFont *afont = PANGO_ATSUI_FONT (font);
   ATSUStyle style;
   ATSUFontID fontID;
-  ATSUAttributeTag styleTags[] =
-    { kATSUFontTag };
+  ATSUAttributeTag styleTags[] = { kATSUFontTag };
   ATSUAttributeValuePtr styleValues[] = { &fontID };
-  ByteCount styleSizes[] =
-    { sizeof(ATSUFontID) };
+  ByteCount styleSizes[] = { sizeof (ATSUFontID) };
 
   utf16 = g_utf8_to_utf16 (text, length, NULL, &n16, NULL);
 
@@ -127,7 +97,7 @@ basic_engine_shape (PangoEngineShape    *engine,
   err = ATSUSetTextPointerLocation (text_layout, utf16, 0, n16, n16);
 
   err = ATSUCreateStyle(&style);
-  fontID = pango_cairo_atsui_font_get_atsu_font_id (cafont);
+  fontID = pango_atsui_font_get_atsu_font_id (afont);
 
   err = ATSUSetAttributes(style,
 			  sizeof(styleTags) / sizeof(styleTags[0]),
@@ -141,7 +111,6 @@ basic_engine_shape (PangoEngineShape    *engine,
 						       (void *)&layout_records,
 						       &glyph_count);
 
-
   p = text;
   pango_glyph_string_set_size (glyphs, glyph_count - 1);
 
